# -*- coding: utf-8 -*-
#This file is part of numword.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.

from unittest import TestCase, main


class TestNumWordFR(TestCase):

    def test_cardinal(self):
        from numword.numword_fr import cardinal
        self.assertEqual(cardinal(0), u"zéro")
        self.assertEqual(cardinal(11.96), u"onze virgule quatre-vingt-seize")
        self.assertEqual(cardinal(100), u"cent")
        self.assertEqual(cardinal(100.0), u"cent")
        self.assertEqual(cardinal(121.01), u"cent-vingt-et-un virgule un")
        self.assertEqual(cardinal(3121.45),
            u"trois-mille-cent-vingt-et-un virgule quarante-cinq")

    def test_cardinal_not_a_number(self):
        from numword.numword_fr import cardinal
        error = u"type\(Ximinez\) not in \[long, int, float\]"
        with self.assertRaisesRegexp(TypeError, error):
            cardinal('Ximinez')

    def test_cardinal_number_too_big(self):
        from numword.numword_fr import cardinal
        from numword.numword_fr import NumWordFR
        max_val = NumWordFR().maxval
        number = max_val + 1
        error = u"abs\(%s\) must be less than %s" % (number, max_val)
        with self.assertRaisesRegexp(OverflowError, error):
            cardinal(number)


class TestNumWordFR_BE(TestCase):

    def test_cardinal(self):
        from numword.numword_fr_be import cardinal
        self.assertEqual(cardinal(72), u"septante-deux")
        self.assertEqual(cardinal(94), u"nonante-quatre")
        self.assertEqual(cardinal(93.79),
            u"nonante-trois virgule septante-neuf")


class TestNumWordEN(TestCase):

    def test_cardinal(self):
        from numword.numword_en import cardinal
        self.assertEqual(cardinal(11.96), u"eleven point ninety-six")
        self.assertEqual(cardinal(100), "one hundred")
        self.assertEqual(cardinal(100.0), "one hundred")
        self.assertEqual(cardinal(121.01),
            "one hundred and twenty-one point one")
        self.assertEqual(cardinal(3121.45),
            u"three thousand, one hundred and twenty-one point forty-five")

    def test_cardinal_not_a_number(self):
        from numword.numword_en import cardinal
        error = u"type\(Ximinez\) not in \[long, int, float\]"
        with self.assertRaisesRegexp(TypeError, error):
            cardinal('Ximinez')

    def test_cardinal_number_too_big(self):
        from numword.numword_en import cardinal
        from numword.numword_en import NumWordEN
        max_val = NumWordEN().maxval
        number = max_val + 1
        error = u"abs\(%s\) must be less than %s" % (number, max_val)
        with self.assertRaisesRegexp(OverflowError, error):
            cardinal(number)


class TestNumWordDE(TestCase):

    def test_cardinal(self):
        from numword.numword_de import cardinal
        tests = [
            [-1.0000100, u"minus eins Komma null"],
            [1.11, u"eins Komma eins eins"],
            [1, u"eins"],
            [11, u"elf"],
            [12, u"zwölf"],
            [21, u"einundzwanzig"],
            [29, u"neunundzwanzig"],
            [30, u"dreißig"],
            [31, u"einunddreißig"],
            [33, u"dreiunddreißig"],
            [71, u"einundsiebzig"],
            [80, u"achtzig"],
            [81, u"einundachtzig"],
            [91, u"einundneunzig"],
            [99, u"neunundneunzig"],
            [100, u"einhundert"],
            [101, u"einhunderteins"],
            [102, u"einhundertzwei"],
            [151, u"einhunderteinundfünfzig"],
            [155, u"einhundertfünfundfünfzig"],
            [161, u"einhunderteinundsechzig"],
            [180, u"einhundertachtzig"],
            [300, u"dreihundert"],
            [301, u"dreihunderteins"],
            [308, u"dreihundertacht"],
            [832, u"achthundertzweiunddreißig"],
            [1000, u"eintausend"],
            [1001, u"eintausendeins"],
            [1061, u"eintausendeinundsechzig"],
            [1100, u"eintausendeinhundert"],
            [1111, u"eintausendeinhundertelf"],
            [1500, u"eintausendfünfhundert"],
            [1701, u"eintausendsiebenhunderteins"],
            [3000, u"dreitausend"],
            [8280, u"achttausendzweihundertachtzig"],
            [8291, u"achttausendzweihunderteinundneunzig"],
            [10100, u"zehntausendeinhundert"],
            [10101, u"zehntausendeinhunderteins"],
            [10099, u"zehntausendneunundneunzig"],
            [12000, u"zwölftausend"],
            [150000, u"einhundertfünfzigtausend"],
            [500000, u"fünfhunderttausend"],
            [1000000, u"eine Million"],
            [1000100, u"eine Million einhundert"],
            [1000199, u"eine Million einhundertneunundneunzig"],
            [2000000, u"zwei Millionen"],
            [2000001, u"zwei Millionen eins"],
            [1000000000, u"eine Milliarde"],
            [2147483647, u"zwei Milliarden einhundertsiebenundvierzig"
                u" Millionen vierhundertdreiundachtzigtausend"
                u"sechshundertsiebenundvierzig"],
                [23000000000, u"dreiundzwanzig Milliarden"],
                [126000000000001, u"einhundertsechsundzwanzig Billionen eins"],
                [-121211221211111, u"minus einhunderteinundzwanzig Billionen "
                    u"zweihundertelf Milliarden zweihunderteinundzwanzig "
                    u"Millionen zweihundertelftausendeinhundertelf"],
                [1000000000000000, u"eine Billiarde"],
                [256000000000000000, u"zweihundertsechsundfünfzig Billiarden"],
                # I know the next is wrong! but what to do?
                [-2.12, u"minus zwei Komma eins zwei"],
                [7401196841564901869874093974498574336000000000,
                    u"sieben Septilliarden vierhunderteins Septillionen "
                    u"einhundertsechsundneunzig Sextilliarden "
                    u"achthunderteinundvierzig Sextillionen fünfhundertvi"
                    u"erundsechzig Quintilliarden neunhunderteins "
                    u"Quintillionen achthundertneunundsechzig Quadrilliarden "
                    u"achthundertvierundsiebzig Quadrillionen dreiundneunzig "
                    u"Trilliarden neunhundertvierundsiebzig Trillionen "
                    u"vierhundertachtundneunzig Billiarden fünfhundertvieru"
                    u"ndsiebzig Billionen dreihundertsechsunddreißig "
                    u"Milliarden"],
                ]
        for number, word in tests:
            self.assertEqual(cardinal(number), word)

    def test_year(self):
        from numword.numword_de import year
        tests = [
            # Watch out, negative years are broken!
            [0, u"null"],
            [33, u"dreiunddreißig"],
            [150, u"einhundertfünfzig"],
            [160, u"einhundertsechzig"],
            [1130, u"elfhundertdreißig"],
            [1999, u"neunzehnhundertneunundneunzig"],
            [1984, u"neunzehnhundertvierundachtzig"],
            [2000, u"zweitausend"],
            [2001, u"zweitausendeins"],
            [2010, u"zweitausendzehn"],
            [2012, u"zweitausendzwölf"],
            ]
        for number, word in tests:
            self.assertEqual(year(number), word)

    def test_currency(self):
        from numword.numword_de import currency
        tests = [
            [12222, u"einhundertzweiundzwanzig Euro und zweiundzwanzig Cent"],
            [123322, u"eintausendzweihundertdreiunddreißig Euro und "
                u"zweiundzwanzig Cent"],
            [686412,
                u"sechstausendachthundertvierundsechzig Euro und zwölf Cent"],
            [84, u"vierundachtzig Cent"],
            [1, u"ein Cent"],
            ]
        for number, word in tests:
            self.assertEqual(currency(number), word)

    def test_ordinal(self):
        from numword.numword_de import ordinal
        tests = [
            [1, u"erste"],
            [3, u"dritte"],
            [11, u"elfte"],
            [12, u"zwölfte"],
            [21, u"einundzwanzigste"],
            [29, u"neunundzwanzigste"],
            [30, u"dreißigste"],
            [31, u"einunddreißigste"],
            [33, u"dreiunddreißigste"],
            [71, u"einundsiebzigste"],
            [80, u"achtzigste"],
            [81, u"einundachtzigste"],
            [91, u"einundneunzigste"],
            [99, u"neunundneunzigste"],
            [100, u"einhundertste"],
            [101, u"einhunderterste"],
            [102, u"einhundertzweite"],
            [151, u"einhunderteinundfünfzigste"],
            [155, u"einhundertfünfundfünfzigste"],
            [161, u"einhunderteinundsechzigste"],
            [180, u"einhundertachtzigste"],
            [300, u"dreihundertste"],
            [301, u"dreihunderterste"],
            [308, u"dreihundertachte"],
            [832, u"achthundertzweiunddreißigste"],
            [1000, u"eintausendste"],
            [1001, u"eintausenderste"],
            [1061, u"eintausendeinundsechzigste"],
            [2000001, u"zwei Millionen erste"],
            # The following is broken
            #[1000000000, "eine Milliardeste"],
            [2147483647, u"zwei Milliarden einhundertsiebenundvierzig"
                u" Millionen vierhundertdreiundachtzigtausend"
                u"sechshundertsiebenundvierzigste"],

            ]
        for number, word in tests:
            self.assertEqual(ordinal(number), word)


class TestNumWordES(TestCase):

    def test_cardinal(self):
        from numword.numword_es import cardinal
        self.assertEqual(cardinal(0), u"cero")
        self.assertEqual(cardinal(11.96), u"once punto noventa y seis")
        self.assertEqual(cardinal(100), u"cien")
        self.assertEqual(cardinal(100.0), u"cien")
        self.assertEqual(cardinal(121.01), u"ciento veintiuno punto uno")
        self.assertEqual(cardinal(3121.45),
            u"tres mil ciento veintiuno punto cuarenta y cinco")
        self.assertEqual(cardinal(41907631),
            u"cuarenta y un millones novecientos siete mil seiscientos "
            u"treinta y uno")

    def test_cardinal_not_a_number(self):
        from numword.numword_es import cardinal
        error = u"type\(Ximinez\) not in \[long, int, float\]"
        with self.assertRaisesRegexp(TypeError, error):
            cardinal('Ximinez')

    def test_cardinal_number_too_big(self):
        from numword.numword_es import cardinal
        from numword.numword_es import NumWordES
        max_val = NumWordES().maxval
        number = max_val + 1
        error = u"abs\(%s\) must be less than %s" % (number, max_val)
        with self.assertRaisesRegexp(OverflowError, error):
            cardinal(number)

if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-
#This file is part of numword.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.
'''
numword for DE
'''
from .numword_eu import NumWordEU

#//TODO: Use German error messages


class NumWordDE(NumWordEU):
    '''
    NumWord DE
    '''
    def _set_high_numwords(self, high):
        '''
        Set high num words
        '''
        max = 3 + 6 * len(high)

        for word, n in zip(high, range(max, 3, -6)):
            self.cards[10 ** n] = word + u"illiarde"
            self.cards[10 ** (n - 3)] = word + u"illion"

    def _setup(self):
        '''
        Setup
        '''
        self.negword = u"minus "
        self.pointword = u"Komma"
        self.exclude_title = []
        lows = [
            u"Non",
            u"Okt",
            u"Sept",
            u"Sext",
            u"Quint",
            u"Quadr",
            u"Tr",
            u"B",
            u"M",
            ]
        units = [
            u"",
            u"Un",
            u"Do",
            u"Tre",
            u"Quattuor",
            u"Quin",
            u"Sex",
            u"Septem",
            u"Okto",
            u"Novem",
            ]
        tens = [
            u"Dezi",
            u"Vigint",
            u"Trigint",
            u"Quadragint",
            u"Quinquagint",
            u"Sexagint",
            u"Septuagint",
            u"Oktogint",
            u"Nonagint",
            ]
        self.high_numwords = ([u"zent"]
            + self._gen_high_numwords(units, tens, lows))
        self.mid_numwords = [
            (1000, u"tausend"),
            (100, u"hundert"),
            (90, u"neunzig"),
            (80, u"achtzig"),
            (70, u"siebzig"),
            (60, u"sechzig"),
            (50, u"fünfzig"),
            (40, u"vierzig"),
            (30, u"dreißig"),
            (20, u"zwanzig"),
            (19, u"neunzehn"),
            (18, u"achtzehn"),
            (17, u"siebzehn"),
            (16, u"sechzehn"),
            (15, u"fünfzehn"),
            (14, u"vierzehn"),
            (13, u"dreizehn"),
            (12, u"zwölf"),
            (11, u"elf"),
            (10, u"zehn"),
            ]
        self.low_numwords = [
            u"neun",
            u"acht",
            u"sieben",
            u"sechs",
            u"fünf",
            u"vier",
            u"drei",
            u"zwei",
            u"eins",
            u"null",
            ]
        self.ords = {
            u"eins": u"ers",
            u"drei": u"drit",
            u"acht": u"ach",
            u"sieben": u"sieb",
            u"hundert": u"hunderts",
            u"tausend": u"tausends",
            u"million": u"millionens",
            u"ig": u"igs",
            }
        self.ordflag = False

    def _cardinal_float(self, value):
        '''
        Convert float to cardinal
        '''
        assert float(value) == value, self.errmsg_nonnum % value
        pre = int(round(value))
        post = abs(value - pre)
        out = [self.cardinal(pre)]
        if self.precision:
            out.append(self._title(self.pointword))

            decimal = int(round(post * (10 ** self.precision)))
            for digit in tuple([x for x in str(decimal)]):
                out.append(str(self.cardinal(int(digit))))
                number = " ".join(out)
        return number

    def _merge(self, curr, next):
        '''
        Merge
        '''
        ctext, cnum, ntext, nnum = curr + next
        if cnum == 1:
            if nnum == 100 or nnum == 10 ** 3:
                return (u"ein" + ntext, nnum)
            if nnum >= 10 ** 6 and not (nnum % 10 ** 3):
                return (u"eine " + ntext.capitalize(), nnum)
            return next
        if nnum > cnum:
            if nnum >= 10 ** 6:
                if ntext[-1] == u"e":
                    ntext = ntext[:-1]
                if cnum > 1:
                    ntext += u"en"
                ctext += " "
            val = cnum * nnum
        else:
            if nnum < 10 < cnum < 100:
                if nnum == 1:
                    ntext = u"ein"
                ntext, ctext = ctext, ntext + u"und"
            elif nnum < 10 < cnum < 1000:
                if nnum == 1:
                    ntext = u"eins"
                ntext, ctext = ntext, ctext
            if cnum >= 10 ** 6 and nnum != 0:
                ctext += " "
            val = cnum + nnum

        word = ctext + ntext
        return (word.strip(), val)

    def ordinal(self, value):
        '''
        Convert to ordinal
        '''
        self._verify_ordinal(value)
        self.ordflag = True
        outword = self.cardinal(value)
        self.ordflag = False
        for key in self.ords:
            if outword.endswith(key):
                outword = outword[:len(outword) - len(key)] + self.ords[key]
                break
        return outword + u"te"

    def ordinal_number(self, value):
        '''
        Convert to ordinal number
        '''
        self._verify_ordinal(value)
        return str(value) + u"te"

    def currency(self, val, longval=True, old=False, hightxt=False,
            lowtxt=False, space=True):
        '''
        Convert to currency
        '''
        if old:
            return self._split(val, hightxt=u"Mark", lowtxt=u"Pfennig(e)",
                jointxt=u"und", longval=longval)
        curr = super(NumWordDE, self).currency(val, jointxt=u"und",
            hightxt=u"Euro", lowtxt=u"Cent", longval=longval, space=space)
        return curr.replace(u"eins", u"ein")

    def cardinal(self, value):
        # catch floats and parse decimalplaces
        if isinstance(value, float):
            prefix, suffix = str(value).split(".")
            pre_card = super(NumWordDE, self).cardinal(int(prefix))
            suf_card = self._cardinal_float(float("." + suffix))
            suf_card = suf_card.replace(u"null %s" %
                _NW.pointword, _NW.pointword)
            cardinal = pre_card + " " + suf_card
            return cardinal
        else:
            return super(NumWordDE, self).cardinal(value)

    def year(self, val, longval=True):
        if not (val // 100) % 10:
            return self.cardinal(val)
        year = self._split(val, hightxt=u"hundert", longval=longval,
            space=False)
        if year.count(self.negword) != 0:
            year = year.replace(self.negword, "").strip()
            year = year + u" v. Chr."
        return year.replace(u"eins", u"ein")

_NW = NumWordDE()


def cardinal(value):
    '''
    Convert to cardinal
    '''
    return _NW.cardinal(value)


def ordinal(value):
    '''
    Convert to ordinal
    '''
    return _NW.ordinal(value)


def ordinal_number(value):
    '''
    Convert to ordinal number
    '''
    return _NW.ordinal_number(value)


def currency(value, longval=True, old=False):
    '''
    Convert to currency
    '''
    return _NW.currency(value, longval=longval, old=old)


def year(value):
    '''
    Convert to year
    '''
    return _NW.year(value)



#This file is part of numword.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.
'''
numword for EN
'''

from .numword_eu import NumWordEU


class NumWordEN(NumWordEU):
    '''
    NumWord EN
    '''

    def _set_high_numwords(self, high):
        '''
        Set high num words
        '''
        max_val = 3 + 3 * len(high)
        for word, i in zip(high, range(max_val, 3, -3)):
            self.cards[10 ** i] = word + u"illion"

    def _setup(self):
        '''
        Setup
        '''
        self.negword = u"minus "
        self.pointword = u"point"
        self.exclude_title = [u"and", u"point", u"minus"]

        self.mid_numwords = [
            (1000, u"thousand"),
            (100, u"hundred"),
            (90, u"ninety"),
            (80, u"eighty"),
            (70, u"seventy"),
            (60, u"sixty"),
            (50, u"fifty"),
            (40, u"forty"),
            (30, u"thirty"),
            ]
        self.low_numwords = [
            u"twenty",
            u"nineteen",
            u"eighteen",
            u"seventeen",
            u"sixteen",
            u"fifteen",
            u"fourteen",
            u"thirteen",
            u"twelve",
            u"eleven",
            u"ten",
            u"nine",
            u"eight",
            u"seven",
            u"six",
            u"five",
            u"four",
            u"three",
            u"two",
            u"one",
            u"zero",
            ]
        self.ords = {
            u"one": u"first",
            u"two": u"second",
            u"three": u"third",
            u"five": u"fifth",
            u"eight": u"eighth",
            u"nine": u"ninth",
            u"twelve": u"twelfth",
            }

    def _merge(self, curr, next):
        '''
        Merge
        '''
        ctext, cnum, ntext, nnum = curr + next

        if cnum == 1 and nnum < 100:
            return next
        elif 100 > cnum > nnum:
            return (u"%s-%s" % (ctext, ntext), cnum + nnum)
        elif cnum >= 100 > nnum:
            return (u"%s and %s" % (ctext, ntext), cnum + nnum)
        elif nnum > cnum:
            return (u"%s %s" % (ctext, ntext), cnum * nnum)
        return (u"%s, %s" % (ctext, ntext), cnum + nnum)

    def ordinal(self, value):
        '''
        Convert to ordinal
        '''
        self._verify_ordinal(value)
        outwords = self.cardinal(value).split(" ")
        lastwords = outwords[-1].split("-")
        lastword = lastwords[-1].lower()
        try:
            lastword = self.ords[lastword]
        except KeyError:
            if lastword[-1] == u"y":
                lastword = lastword[:-1] + u"ie"
            lastword += u"th"
        lastwords[-1] = self._title(lastword)
        outwords[-1] = u"-".join(lastwords)
        return " ".join(outwords)

    def ordinal_number(self, value):
        '''
        Convert to ordinal num
        '''
        self._verify_ordinal(value)
        return u"%s%s" % (value, self.ordinal(value)[-2:])

    def year(self, val, longval=True):
        '''
        Convert to year
        '''
        if not (val // 100) % 10:
            return self.cardinal(val)
        return self._split(val, hightxt=u"hundred", jointxt=u"and",
            longval=longval)

    def currency(self, val, longval=True):
        '''
        Convert to currency
        '''
        return self._split(val, hightxt=u"dollar/s", lowtxt=u"cent/s",
            jointxt=u"and", longval=longval)


_NW = NumWordEN()


def cardinal(value):
    '''
    Convert to cardinal
    '''
    return _NW.cardinal(value)


def ordinal(value):
    '''
    Convert to ordinal
    '''
    return _NW.ordinal(value)


def ordinal_number(value):
    '''
    Convert to ordinal num
    '''
    return _NW.ordinal_number(value)


def currency(value, longval=True):
    '''
    Convert to currency
    '''
    return _NW.currency(value, longval=longval)


def year(value, longval=True):
    '''
    Convert to year
    '''
    return _NW.year(value, longval=longval)



#This file is part of numword.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.
'''
numword base
'''

import math
from collections import OrderedDict


class NumWordBase(object):
    '''
    NumWordBase
    '''

    def __init__(self):
        self.cards = OrderedDict()
        self.is_title = False
        self.precision = 2
        self.exclude_title = []
        self.negword = u"(-) "
        self.pointword = u"(.)"
        self.errmsg_nonnum = u"type(%s) not in [long, int, float]"
        self.errmsg_floatord = u"Cannot treat float %s as ordinal."
        self.errmsg_negord = u"Cannot treat negative num %s as ordinal."
        self.errmsg_toobig = u"abs(%s) must be less than %s."

        self.high_numwords = None
        self.mid_numwords = None
        self.low_numwords = None
        self.ords = None

        self._base_setup()
        self._setup()
        self._set_numwords()

        self.maxval = 1000 * self.cards.iterkeys().next()

    def _base_setup(self):
        '''
        Base Setup
        '''
        pass

    def _setup(self):
        '''
        Setup
        '''
        pass

    def _set_numwords(self):
        '''
        Set num words
        '''
        self._set_high_numwords(self.high_numwords)
        self._set_mid_numwords(self.mid_numwords)
        self._set_low_numwords(self.low_numwords)

    def _set_high_numwords(self, high):
        '''
        Set high num words
        '''
        pass

    def _set_mid_numwords(self, mid):
        '''
        Set mid num words
        '''
        for key, val in mid:
            self.cards[key] = val

    def _set_low_numwords(self, low):
        '''
        Set low num words
        '''
        for word, i in zip(low, range(len(low) - 1, -1, -1)):
            self.cards[i] = word

    @staticmethod
    def _gen_high_numwords(units, tens, lows):
        '''
        Generate high num words
        '''
        out = [u + t for t in tens for u in units]
        out.reverse()
        return out + lows

    def _splitnum(self, value):
        '''
        Split num
        '''
        for elem in self.cards:
            if elem > value:
                continue
            out = []
            if value == 0:
                div, mod = 1, 0
            else:
                div, mod = divmod(value, elem)

            if div == 1:
                out.append((self.cards[1], 1))
            else:
                if div == value:  # The system tallies, eg Roman Numerals
                    return [(div * self.cards[elem], div * elem)]
                out.append(self._splitnum(div))

            out.append((self.cards[elem], elem))

            if mod:
                out.append(self._splitnum(mod))
            return out

    def _merge(self, curr, next):
        '''
        Merge
        '''
        raise NotImplementedError

    def _clean(self, val):
        '''
        Clean
        '''
        out = val
        while len(val) != 1:
            out = []
            curr, next = val[:2]
            if isinstance(curr, tuple) and isinstance(next, tuple):
                out.append(self._merge(curr, next))
                if val[2:]:
                    out.append(val[2:])
            else:
                for elem in val:
                    if isinstance(elem, list):
                        if len(elem) == 1:
                            out.append(elem[0])
                        else:
                            out.append(self._clean(elem))
                    else:
                        out.append(elem)
            val = out
        return out[0]

    def _title(self, value):
        '''
        Return title
        '''
        if self.is_title:
            out = []
            value = value.split()
            for word in value:
                if word in self.exclude_title:
                    out.append(word)
                else:
                    out.append(word[0].upper() + word[1:])
            value = " ".join(out)
        return value

    def _verify_ordinal(self, value):
        '''
        Verify ordinal
        '''
        if not value == long(value):
            raise TypeError(self.errmsg_floatord % (value))
        if not abs(value) == value:
            raise TypeError(self.errmsg_negord % (value))

    def _verify_num(self, value):
        '''
        Verify num
        '''
        return 1

    def _set_wordnums(self):
        '''
        Set word nums
        '''
        pass

    def _cardinal_float(self, value):
        '''
        Convert float to cardinal
        '''
        try:
            assert float(value) == value
        except (ValueError, TypeError, AssertionError):
            raise TypeError(self.errmsg_nonnum % value)

        pre = int(math.floor(value))
        post = abs(value - pre)

        out = [self.cardinal(pre)]
        if self.precision:
            out.append(self._title(self.pointword))

            decimal = int(round(post * (10 ** self.precision)))
            out.append(str(self.cardinal(decimal)))

        return " ".join(out)

    def cardinal(self, value):
        '''
        Convert long to cardinal
        '''
        try:
            assert long(value) == value
        except (ValueError, TypeError, AssertionError):
            return self._cardinal_float(value)

        self._verify_num(value)

        out = ""
        if value < 0:
            value = abs(value)
            out = self.negword

        if value >= self.maxval:
            raise OverflowError(self.errmsg_toobig % (value, self.maxval))

        val = self._splitnum(value)
        words, _ = self._clean(val)
        return self._title(out + words)

    def ordinal(self, value):
        '''
        Convert to ordinal
        '''
        return self.cardinal(value)

    def ordinal_number(self, value):
        '''
        Convert to ordinal number
        '''
        return value

    def _inflect(self, value, text):
        '''
        Inflect
        '''
        text = text.split("/")
        if value == 1:
            return text[0]
        return "".join(text)

    def _split(self, val, hightxt="", lowtxt="", jointxt="", precision=2,
            longval=True, space=True):
        '''
        Split
        '''
        out = []
        try:
            high, low = val
        except TypeError:
            high, low = divmod(val, (10 ** precision))
            #high = int(val)
            #low = int(round((val - high) * (10**precision)))
        if high:
            hightxt = self._title(self._inflect(high, hightxt))
            out.append(self.cardinal(high))
            if low:
                if longval:
                    if hightxt:
                        out.append(hightxt)
                    if jointxt:
                        out.append(self._title(jointxt))
            elif hightxt:
                out.append(hightxt)
        if low:
            out.append(self.cardinal(low))
            if lowtxt and longval:
                out.append(self._title(self._inflect(low, lowtxt)))
        if space:
            return " ".join(out)
        else:
            return "".join(out)

    def year(self, value, **kwargs):
        '''
        Convert to year
        '''
        return self.cardinal(value)

    def currency(self, value, **kwargs):
        '''
        Convert to currency
        '''
        return self.cardinal(value)



#!/usr/bin/env python
#This file is part of numword.  The COPYRIGHT file at the top level of
#this repository contains the full copyright notices and license terms.

import os
import re
from setuptools import setup, find_packages


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


def get_version():
    init = read(os.path.join('numword', '__init__.py'))
    return re.search("__version__ = '([0-9.]*)'", init).group(1)


setup(name='psk_numword',
    version=get_version(),
    author='Presik Technologies',
    author_email='gerente@presik.com',
    url="https://bitbucket.org/presik/psk_numword",
    description="Python modules to convert numbers to words",
    download_url="https://bitbucket.org/presik/psk_numword/downloads",
    packages=find_packages(),
    test_suite='numword.tests',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU Library or Lesser General Public License (LGPL)',
        'Natural Language :: English',
        'Natural Language :: French',
        'Natural Language :: German',
        'Natural Language :: Spanish',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Internationalization',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Software Development :: Localization',
        'Topic :: Text Processing :: Linguistic',
        ],
    license='LGPL',
    use_2to3=True)
